summaryrefslogtreecommitdiffstats
path: root/ui/gfx/platform_font_mac.h
diff options
context:
space:
mode:
Diffstat (limited to 'ui/gfx/platform_font_mac.h')
-rw-r--r--ui/gfx/platform_font_mac.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/ui/gfx/platform_font_mac.h b/ui/gfx/platform_font_mac.h
index aa85f82..d8f8e85 100644
--- a/ui/gfx/platform_font_mac.h
+++ b/ui/gfx/platform_font_mac.h
@@ -7,6 +7,7 @@
#include "base/compiler_specific.h"
#include "base/mac/scoped_nsobject.h"
+#include "ui/gfx/font_render_params.h"
#include "ui/gfx/platform_font.h"
namespace gfx {
@@ -35,8 +36,8 @@ class PlatformFontMac : public PlatformFont {
PlatformFontMac(const std::string& font_name, int font_size, int font_style);
~PlatformFontMac() override;
- // Calculates and caches the font metrics.
- void CalculateMetrics();
+ // Calculates and caches the font metrics and inits |render_params_|.
+ void CalculateMetricsAndInitRenderParams();
// The NSFont instance for this object. If this object was constructed from an
// NSFont instance, this holds that NSFont instance. Otherwise this NSFont
@@ -56,6 +57,9 @@ class PlatformFontMac : public PlatformFont {
int cap_height_;
int average_width_;
+ // Details about how the font should be rendered.
+ FontRenderParams render_params_;
+
DISALLOW_COPY_AND_ASSIGN(PlatformFontMac);
};